import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

/**
 * MyWorld functions as the Controller for this Greenfoot
 * project which helps students understand inheritance
 * 
 * @Jordan Cohen
 * @Feb 2012
 */
public class MyWorld extends World
{
    private int randomize;
    /**
     * Spawn Rates:
     * Lower number means more spawns
     * 3:spawnRate chance per act of spawning a random Vehicle
     * 1:pedSpawn chance per act of spawning a Pedestrian
     */
    private int spawnRate = 140;
    private int pedSpawn = 80;
    private final int reimuLimit = 1;
    private int reimuOnScreen = 0;
    private final int ctLimit = 2;
    private int ctOnScreen = 0;
    /**
     * Constructor for objects of class MyWorld.
     * 
     */
    public MyWorld()
    {    
        // Create a new world with 600x400 cells with a cell size of 1x1 pixels.
        super(600, 400, 1, false); 
        setPaintOrder(Vehicle.class, Pedestrian.class);
    }

    public void act ()
    {
        // spawn pedestrians
        if (Greenfoot.getRandomNumber(pedSpawn) == 1)
        {
            addObject (new NormalPedestrian(), Greenfoot.getRandomNumber(600), 395);
        }
        else if (Greenfoot.getRandomNumber(pedSpawn) == 2)
        {
            addObject (new Trolldestrian(), Greenfoot.getRandomNumber(600), 395);
        }
        else if (Greenfoot.getRandomNumber(pedSpawn) == 3 && reimuOnScreen != reimuLimit)
        {
            addObject (new Reimu(), Greenfoot.getRandomNumber(600),395);
            reimuOnScreen++;
        }
        else if (Greenfoot.getRandomNumber(pedSpawn) == 4 && ctOnScreen != ctLimit)
        {
            addObject (new CounterTerrorist(), Greenfoot.getRandomNumber(600),395);
            ctOnScreen++;
        }

        if (Greenfoot.getRandomNumber(200) == 1)
        {
            addObject(new Pacman(), 5, 370);
        }
        if (Greenfoot.getRandomNumber(200) == 1)
        {
            addObject(new Pacman(), 5, 20);
        }

        // Generate a random number to add a random element
        // to Vehicle spawning
        randomize = Greenfoot.getRandomNumber(spawnRate);

        // Chose a random lane in case a vehicle spawns
        int lane = Greenfoot.getRandomNumber (6);
        int spawnY = getYPosition (lane);

        // spawn vehicles
        if (randomize == 1)
        {
            // spawn a Car
            addObject (new Car(), 10, spawnY);
        }
        else if (randomize == 2)
        {
            // spawn a Bus
            addObject (new Bus(), 10, spawnY);
        }

        else if (randomize == 3)
        {
            // spawn a Car
            addObject (new Ambulance(), 10, spawnY);
        }

        else if (randomize == 4)
        {
            addObject(new Killer(), 10,spawnY);
        }

    }

    /**
     * Returns the appropriate y coordinate for a given lane
     */
    private int getYPosition (int inLane)
    {
        // Manually input values based on the background graphic
        switch (inLane)
        {
            case 0: 
            return 79;

            case 1:
            return 127;

            case 2:
            return 175;

            case 3:
            return 222;

            case 4:
            return 272;

            case 5: 
            return 320;

        }  
        // In case an invalid value is passed in
        return 0;
    }

    public void resetReimuCount()
    {
        reimuOnScreen--;
    }

    public void resetCtCount()
    {
        ctOnScreen--;
    }
}

