import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)
import java.util.Random;
/**
 * Pedestrian Class
 * 
 * Moves mindlessly up the road, reacting to cars
 * that hit it, ambulances that heal it, and potentially
 * buses that pick it up.
 * 
 * @Jordan Cohen
 * 
 */

public class NormalPedestrian extends Pedestrian
{
    // Instance variables
    private int myWidth;
    private boolean healthy;
    private int startSpeed = 2;
    private int speed;
    private boolean isDead = false;
    private boolean dragged = false;

    // Constructor
    public NormalPedestrian()
    {
        // figure out own width (related to checking if at world's edge)
        GreenfootImage g = this.getImage();
        myWidth = g.getWidth();

        // Set current healthy status to true (alive and moving)
        healthy = true;
        // Set initial speed
        speed = startSpeed;
    }

    // act() method - called by Greenfoot at every
    // "act" or step of execution
    public void act() 
    {
        // move upwards
        setLocation (getX(), getY() - speed);
        // check if I'm at the edge of the world,
        // and if so, remove myself
        drag();
        if (atWorldEdge())
        {
            getWorld().removeObject(this);
        }
    }    

    /**
     * Method causes this Pedestrian to stop moving
     * and appear to fall over
     */
    public void knockMeOver ()
    {
        if (isDead == false)
        {
            speed = 0;
            setRotation (90);
            playDeathSound();
            isDead = true;
        }
    }

    /**
     * Method causes this pedestrian to "heal" - regain
     * upright position and start moving again
     */
    public void healMe ()
    {
        if (isDead == true)
        {
            speed = startSpeed;
            setRotation (0);
            healed.play();
            isDead = false;
        }
    }

    /**
     * Handy method that checks if this object is at the edge
     * of the World
     */
    public boolean atWorldEdge()
    {
        if (getX() < -(myWidth / 2) || getX() > getWorld().getWidth() + (myWidth / 2))
            return true;
        else if (getY() < -(myWidth / 2) || getY () > getWorld().getHeight() + (myWidth / 2))
            return true;
        else
            return false;
    }

    /**
     * Method that plays a sound effect when the pedestrian is run over
     */
    public void playDeathSound()
    {
        Random r = new Random();
        int a;
        a = r.nextInt(6);
        switch (a)
        {
            case 0:
            death1.play();
            break;
            case 1:
            death2.play();
            break;
            case 2:
            death3.play();
            break;
            case 3:
            death4.play();
            break;
            case 4:
            death5.play();
            break;
            case 5:
            death6.play();
            break;
        }
    }

    /**
     * Method that allows a bus to drag dead pedestrians off screen
     */
    public void drag()
    {
        if (isDead == true)
        {
            Draggers b = (Draggers)getOneIntersectingObject(Draggers.class);

            if (b != null)
            {
                setLocation(b.getX() - 20, b.getY());
                if (dragged == false)
                {
                    setRotation(270);
                    playDeathSound();
                    dragged = true;
                }
            }
        }
    }
}
