import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

/**
 * Pedestrian Class
 * 
 * Moves mindlessly up the road, reacting to cars
 * that hit it, ambulances that heal it, and potentially
 * buses that pick it up.
 * 
 * @Jordan Cohen
 * 
 */
import java.util.Random;
public abstract class Pedestrian extends Actor
{
    // Instance variables
    private int myWidth;
    private boolean healthy;
    private int startSpeed = 2;
    private int speed;
    private boolean isDead = false;
    private boolean dragged = false;
    GreenfootSound death1 = new GreenfootSound("death1.wav");
    GreenfootSound death2 = new GreenfootSound("death2.wav");
    GreenfootSound death3 = new GreenfootSound("death3.wav");
    GreenfootSound death4 = new GreenfootSound("death4.wav");
    GreenfootSound death5 = new GreenfootSound("death5.wav");
    GreenfootSound death6 = new GreenfootSound("death6.wav");

    GreenfootSound healed = new GreenfootSound("healed.wav");

    // act() method - called by Greenfoot at every
    // "act" or step of execution
    public abstract void act() ;

    /**
     * Method causes this Pedestrian to stop moving
     * and appear to fall over
     */
    public abstract void knockMeOver ();

    /**
     * Method causes this pedestrian to "heal" - regain
     * upright position and start moving again
     */
    public abstract void healMe ();

    /**
     * Handy method that checks if this object is at the edge
     * of the World
     */
    public abstract boolean atWorldEdge();

    /**
     * Method that plays a sound effect when the pedestrian is run over
     */
    public abstract void playDeathSound();

    /**
     * Method that allows a bus to drag dead pedestrians off screen
     */
    public abstract void drag();

}
